==> cdes-api-6.13.57-20250310.170352-2.jar: at/cdes/api/person/compositeDto/PersonOwnEditInfo.java <==
/***********************************************************
 * $Id$
 * 
 * Copyright (C) 2002-2006 ev-i Informationstechnologie GmbH
 *
 * Created: 07.11.2023
 *
 * Author: wpausch/ev-i
 * 
 ***********************************************************/

package at.cdes.api.person.compositeDto;

import java.util.List;

import at.cdes.api.dto.Country;
import at.cdes.api.dto.Person;
import at.cdes.api.dto.PersonVariables;
import at.cdes.api.joinDto.OrganisationPersonJoin;

public class PersonOwnEditInfo {
    
    private Person person;
    private PersonVariables personVariables;
    private List<OrganisationPersonJoin> organisationPersonJoins;
    private List<Country> countries;

    public Person getPerson() {
        return this.person;
    }
    public void setPerson(Person person) {
        this.person = person;
    }
    public PersonVariables getPersonVariables() {
        return this.personVariables;
    }
    public void setPersonVariables(PersonVariables personVariables) {
        this.personVariables = personVariables;
    }
    public List<OrganisationPersonJoin> getOrganisationPersonJoins() {
        return this.organisationPersonJoins;
    }
    public void setOrganisationPersonJoins(List<OrganisationPersonJoin> organisationPersonJoins) {
        this.organisationPersonJoins = organisationPersonJoins;
    }
    public List<Country> getCountries() {
        return this.countries;
    }
    public void setCountries(List<Country> countries) {
        this.countries = countries;
    }
}

==> cdes-api-6.15.7-20250307.231416-1.jar: at/cdes/api/person/compositeDto/PersonOwnEditInfo.java <==
/***********************************************************
 * $Id$
 * 
 * Copyright (C) 2002-2006 ev-i Informationstechnologie GmbH
 *
 * Created: 07.11.2023
 *
 * Author: wpausch/ev-i
 * 
 ***********************************************************/

package at.cdes.api.person.compositeDto;

import java.util.List;

import at.cdes.api.dto.Country;
import at.cdes.api.dto.Person;
import at.cdes.api.dto.PersonVariables;
import at.cdes.api.joinDto.OrganisationPersonJoin;

public class PersonOwnEditInfo {
    
    private Person person;
    private PersonVariables personVariables;
    private List<OrganisationPersonJoin> organisationPersonJoins;
    private List<Country> countries;
    private Boolean enableLocaleSelection;

    public Person getPerson() {
        return this.person;
    }
    public void setPerson(Person person) {
        this.person = person;
    }
    public PersonVariables getPersonVariables() {
        return this.personVariables;
    }
    public void setPersonVariables(PersonVariables personVariables) {
        this.personVariables = personVariables;
    }
    public List<OrganisationPersonJoin> getOrganisationPersonJoins() {
        return this.organisationPersonJoins;
    }
    public void setOrganisationPersonJoins(List<OrganisationPersonJoin> organisationPersonJoins) {
        this.organisationPersonJoins = organisationPersonJoins;
    }
    public List<Country> getCountries() {
        return this.countries;
    }
    public void setCountries(List<Country> countries) {
        this.countries = countries;
    }
	public Boolean getEnableLocaleSelection() {
		return this.enableLocaleSelection;
	}
	public void setEnableLocaleSelection(Boolean enableLocaleSelection) {
		this.enableLocaleSelection = enableLocaleSelection;
	}
}
